@@ -1,5 +1,9 @@
-EMS = function(Formula, Data, Type=3, eps=1e-8) 
+EMS = function(Formula, Data, Type=3, eps=1e-8)
 {
+  if (!attr(terms(Formula, data=Data), "response")) stop("Dependent variable should be provided!")
+  y = model.frame(Formula, Data)[,1]
+  if (!is.numeric(y)) stop("Dependent variable should be numeric!")
+
   x = ModelMatrix(Formula, Data)
   Terms = labels(terms(x))
   nTerm = length(Terms)
@@ -9,8 +13,7 @@ EMS = function(Formula, Data, Type=3, eps=1e-8)
               "2" = e2(Formula, Data, eps=eps),
               "3" = e3(Formula, Data, eps=eps),
               stop(paste("Type", Type, "is not supported!")))
-                            
-  y = model.frame(Formula, Data)[,1]
+
   r0 = lfit(x, y)
   b = r0$coefficients
 
@@ -22,8 +25,8 @@ EMS = function(Formula, Data, Type=3, eps=1e-8)
     if (NROW(L) > 0) {
       xC = t(L) %*% G2SWEEP(L %*% G2SWEEP(crossprod(x$X)) %*% t(L)) %*% L
 #      M = qr.solve(t(chol(L %*% G2SWEEP(crossprod(x$X)) %*% t(L)))) # Frequent crash
-#      xC = crossprod(M %*% L)    
-      for (j in 1:nTerm) Res[i,j] = sum(diag(xC[x$assign==j, x$assign==j]))/NROW(L)
+#      xC = crossprod(M %*% L)
+      for (j in 1:nTerm) Res[i,j] = sum(diag(xC[x$assign==j, x$assign==j, drop=FALSE]))/NROW(L)
     } else {
 #      Res[1,] = NA
       Res[i,] = 0
